@@ -1,4 +1,5 @@
-from PyQt5.QtCore import QObject, pyqtSlot, pyqtSignal
+from PyQt5.QtCore import QObject
+from UM.FlameProfiler import pyqtSlot
 
 # This class wraps a Python container and provides access to its elements
 #
