@@ -1,5 +1,5 @@
 # Copyright (c) 2015 Ultimaker B.V.
-# Uranium is released under the terms of the AGPLv3 or higher.
+# Uranium is released under the terms of the LGPLv3 or higher.
 from typing import List, Optional
 
 from UM.Math.Matrix import Matrix
@@ -70,7 +70,7 @@ class SceneNode():
         # Can this SceneNode be selected in any way?
         self._selectable = False  # type: bool
 
-        # Should the AxisAlignedBounxingBox be re-calculated?
+        # Should the AxisAlignedBoundingBox be re-calculated?
         self._calculate_aabb = True  # type: bool
 
         # The AxisAligned bounding box.
@@ -81,6 +81,9 @@ class SceneNode():
         self._name = kwargs.get("name", "")  # type: str
         self._decorators = []  # type: List[SceneNodeDecorator]
 
+        # Store custom settings to be compatible with Savitar SceneNode
+        self._settings = {}
+
         ## Signals
         self.boundingBoxChanged.connect(self.calculateBoundingBoxMesh)
         self.parentChanged.connect(self._onParentChanged)
@@ -623,6 +626,12 @@ class SceneNode():
     def getShear(self) -> Vector:
         return self._shear
 
+    def getSetting(self, key, default_value):
+        return self._settings.get(key, default_value)
+
+    def setSetting(self, key, value):
+        self._settings[key] = value
+
     ##  private:
     def _transformChanged(self):
         self._updateTransformation()
