@@ -1,5 +1,5 @@
 # Copyright (c) 2017 Ultimaker B.V.
-# Uranium is released under the terms of the AGPLv3 or higher.
+# Uranium is released under the terms of the LGPLv3 or higher.
 
 import re
 
@@ -29,6 +29,9 @@ class ContainerQuery:
 
         self._result = None
 
+    def getContainerType(self):
+        return self._container_type
+
     ##  Retrieve the result of this query.
     #
     #   \return A list of containers matching this query, or None if the query was not executed.
@@ -47,7 +50,14 @@ class ContainerQuery:
     #   class' constructor. After it is done, the result can be retrieved with getResult().
     def execute(self):
         containers = []
-        for container in filter(lambda c: not self._container_type or isinstance(c, self._container_type), self._registry._containers):
+
+        # If no container type is specified, search through all containers.
+        if not self._container_type:
+            candidates = self._registry._containers
+        else:
+            candidates = filter(lambda c: isinstance(c, self._container_type), self._registry._containers)
+
+        for container in candidates:
             matches_container = True
             for key, value in self._kwargs.items():
                 if isinstance(value, str):
