@@ -1,5 +1,5 @@
 # Copyright (c) 2017 Ultimaker B.V.
-# Uranium is released under the terms of the AGPLv3 or higher.
+# Uranium is released under the terms of the LGPLv3 or higher.
 
 import os
 import re #For finding containers with asterisks in the constraints and for detecting backup files.
@@ -21,6 +21,7 @@ from UM.Signal import Signal, signalemitter
 from UM.LockFile import LockFile
 
 import UM.Dictionary
+import gc
 
 MYPY = False
 if MYPY:
@@ -32,6 +33,7 @@ from UM.Settings.InstanceContainer import InstanceContainer
 from UM.Settings.Interfaces import ContainerRegistryInterface
 from UM.Settings.Interfaces import DefinitionContainerInterface
 
+import UM.Qt.QtApplication
 from . import ContainerQuery
 
 CONFIG_LOCK_FILENAME = "uranium.lock"
@@ -51,6 +53,8 @@ class ContainerRegistry(ContainerRegistryInterface):
 
         self._containers = [self._emptyInstanceContainer]   # type: List[ContainerInterface]
         self._id_container_cache = {}
+        # Ensure that the empty container is added to the ID cache.
+        self._id_container_cache["empty"] = self._emptyInstanceContainer
         self._resource_types = [Resources.DefinitionContainers] # type: List[int]
         self._query_cache = collections.OrderedDict() # This should really be an ordered set but that does not exist...
 
@@ -115,6 +119,8 @@ class ContainerRegistry(ContainerRegistryInterface):
                     return [ container ]
                 elif isinstance(container, container_type):
                     return [ container ]
+            else:
+                return [] # No result, so return an empty list.
 
         if query in self._query_cache:
             # If the exact same query is in the cache, we can re-use the query result
@@ -143,7 +149,12 @@ class ContainerRegistry(ContainerRegistryInterface):
     #
     #   \note This method does not clear the internal list of containers. This means that any containers
     #   that were already added when the first call to this method happened will not be re-added.
+    @UM.FlameProfiler.profile
     def load(self) -> None:
+        # We disable the garbage collection while loading, as this speeds up the loading.
+        # Since there is so much going on (lots of objects being created), it's better to have it wait a bit until
+        # the dust settles down.
+        gc.disable()
         files = []
         old_file_expression = re.compile(r"\{sep}old\{sep}\d+\{sep}".format(sep = os.sep))
 
@@ -187,6 +198,9 @@ class ContainerRegistry(ContainerRegistryInterface):
         resource_start_time = time.time()
         with self.lockCache(): #Because we might be writing cache files.
             for _, container_id, file_path, read_only, container_type in files:
+                # Enable the rest of the application to get UI updates.
+                UM.Qt.QtApplication.QtApplication.processEvents()
+
                 if container_id in self._id_container_cache:
                     Logger.log("c", "Found a container with a duplicate ID: %s", container_id)
                     Logger.log("c", "Existing container is %s, trying to load %s from %s", self._id_container_cache[container_id], container_type, file_path)
@@ -212,6 +226,7 @@ class ContainerRegistry(ContainerRegistryInterface):
                 except Exception as e:
                     Logger.logException("e", "Could not deserialize container %s", container_id)
             Logger.log("d", "Loading data into container registry took %s seconds", time.time() - resource_start_time)
+            gc.enable()
 
     @UM.FlameProfiler.profile
     def addContainer(self, container: ContainerInterface) -> None:
@@ -225,7 +240,7 @@ class ContainerRegistry(ContainerRegistryInterface):
 
         self._containers.append(container)
         self._id_container_cache[container.getId()] = container
-        self._clearQueryCache()
+        self._clearQueryCacheByContainer(container)
         self.containerAdded.emit(container)
 
     @UM.FlameProfiler.profile
@@ -241,8 +256,7 @@ class ContainerRegistry(ContainerRegistryInterface):
 
             if hasattr(container, "metaDataChanged"):
                 container.metaDataChanged.disconnect(self._onContainerMetaDataChanged)
-
-            self._clearQueryCache()
+            self._clearQueryCacheByContainer(container)
             self.containerRemoved.emit(container)
 
             Logger.log("d", "Removed container %s", container.getId())
@@ -273,8 +287,7 @@ class ContainerRegistry(ContainerRegistryInterface):
             del self._id_container_cache[container._id]
             container._id = new_id
             self._id_container_cache[container._id] = container # Keep cache up-to-date.
-
-        self._clearQueryCache()
+        self._clearQueryCacheByContainer(container)
         self.containerAdded.emit(container)
 
     def saveAll(self) -> None:
@@ -343,6 +356,7 @@ class ContainerRegistry(ContainerRegistryInterface):
     #   \param original The original name that may not be unique.
     #   \return A unique name that looks a lot like the original but may have
     #   a number behind it to make it unique.
+    @UM.FlameProfiler.profile
     def uniqueName(self, original: str) -> str:
         name = original.strip()
 
@@ -478,7 +492,7 @@ class ContainerRegistry(ContainerRegistryInterface):
 
         try:
             with open(cache_path, "wb") as f:
-                pickle.dump(definition, f)
+                pickle.dump(definition, f, pickle.HIGHEST_PROTOCOL)
         except RecursionError:
             #Sometimes a recursion error in pickling occurs here.
             #The cause is unknown. It must be some circular reference in the definition instances or definition containers.
@@ -492,6 +506,26 @@ class ContainerRegistry(ContainerRegistryInterface):
     def _clearQueryCache(self, *args, **kwargs):
         self._query_cache.clear()
 
+    ##  Clear the query cache by using container type.
+    #   This is a slightly smarter way of clearing the cache. Only queries that are of the same type (or without one)
+    #   are cleared.
+    def _clearQueryCacheByContainer(self, container):
+        # Use the base classes to clear the
+        if isinstance(container, DefinitionContainer):
+            container_type = DefinitionContainer
+        elif isinstance(container, InstanceContainer):
+            container_type = InstanceContainer
+        elif isinstance(container, ContainerStack):
+            container_type = ContainerStack
+        else:
+            Logger.log("w", "While clearing query cache, we got an unrecognised base type (%s). Clearing entire cache instead", type(container))
+            self._clearQueryCache()
+            return
+
+        for key in list(self._query_cache.keys()):
+            if self._query_cache[key].getContainerType() == container_type or self._query_cache[key].getContainerType() is None:
+                del self._query_cache[key]
+
     ##  Called when any container's metadata changed.
     #
     #   This function passes it on to the containerMetaDataChanged signal. Sadly
